"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var monad_progress_1 = require("../typeclasses/monad-progress/monad-progress");
function fetchScript(O, A) {
    var fromProgressEventM = monad_progress_1.fromProgressEvent(A);
    return function (src, config) {
        if (config === void 0) { config = {}; }
        return O.fromObservable({
            subscribe: function (observer) {
                var script = document.createElement('script');
                script.async = true;
                script.src = src;
                script.onload = function () {
                    observer.next(A.of(undefined));
                    observer.end();
                };
                script.onerror = function () {
                    observer.next(A.throwError(new Error("Cannot fetch script: " + src)));
                    observer.end();
                };
                if (config.shouldTrackProgress) {
                    script.onprogress = function (e) {
                        observer.next(fromProgressEventM(e));
                    };
                }
                document.body.appendChild(script);
                return {
                    unsubscribe: function () {
                        if (config.shouldRemoveOnDispose) {
                            document.removeChild(script);
                        }
                    },
                };
            },
        });
    };
}
exports.fetchScript = fetchScript;
//# sourceMappingURL=fetch-script.js.map